@@ -5,8 +5,9 @@ use warnings;
 use EV;
 use Net::Curl::Easy qw(CURLE_COULDNT_CONNECT);
 use Net::Curl::Multi qw(CURLMSG_DONE CURL_SOCKET_TIMEOUT /^CURL_POLL_/ /^CURL_CSELECT_/ CURLMOPT_SOCKETFUNCTION CURLMOPT_TIMERFUNCTION);
+use Scalar::Util qw(weaken);
 
-our $VERSION = '0.01.5';
+our $VERSION = '0.01.6';
 
 BEGIN {
 	Net::Curl::Multi->can('CURLMOPT_TIMERFUNCTION') or
@@ -17,8 +18,6 @@ BEGIN {
 sub curl_ev {
 	my ($multi) = @_;
 
-	$multi ||= Net::Curl::Multi->new();
-
 	my %finish = (); # easy => finish
 	my %timer  = (); # easy => sub
 
@@ -141,6 +140,8 @@ sub curl_ev {
 	$multi->setopt(CURLMOPT_SOCKETFUNCTION, $cb_socket);
 	$multi->setopt(CURLMOPT_TIMERFUNCTION,  $cb_timer);
 
+	weaken $multi;
+
 	return $add_handle;
 }
 
